@@ -1,184 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="tr">
-<context>
-    <name>MConfig</name>
-    <message>
-        <source>IP address from router:</source>
-        <translation type="vanished">Yönlendiriciden İP adresi</translation>
-    </message>
-    <message>
-        <source>External IP address:</source>
-        <translation type="vanished">Harici İP adresi:</translation>
-    </message>
-    <message>
-        <source>&amp;Copy</source>
-        <translation type="vanished">&amp;Kopyala</translation>
-    </message>
-    <message>
-        <source>Ctrl+C</source>
-        <translation type="vanished">Ctrl+C</translation>
-    </message>
-    <message>
-        <source>Copy &amp;All</source>
-        <translation type="vanished">&amp;Hepsini Kopyala</translation>
-    </message>
-    <message>
-        <source>Ctrl+A</source>
-        <translation type="vanished">Ctrl+A</translation>
-    </message>
-    <message>
-        <source>Traceroute not installed</source>
-        <translation type="vanished">İz yolu kurulmadı</translation>
-    </message>
-    <message>
-        <source>No destination host</source>
-        <translation type="vanished">Hedef makine yok</translation>
-    </message>
-    <message>
-        <source>*.sys file not found</source>
-        <translation type="vanished">*.sys dosyası bulunamadı</translation>
-    </message>
-    <message>
-        <source>Ndiswrapper driver removed.</source>
-        <translation type="vanished">Ndiswrapper sürücüsü kaldırıldı.</translation>
-    </message>
-    <message>
-        <source>Version: </source>
-        <translation type="vanished">Sürüm</translation>
-    </message>
-    <message>
-        <source>Program for troubleshooting and configuring network for MX Linux</source>
-        <translation type="vanished">MX Linux için ağ yapılandırma ve sorun giderme programı</translation>
-    </message>
-    <message>
-        <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation type="vanished">Copyright (c) MEPIS LLC ve MX Linux</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">Ruhsat</translation>
-    </message>
-    <message>
-        <source>Changelog</source>
-        <translation type="vanished">Değişim günlüğü</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">İptal</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Kapat</translation>
-    </message>
-</context>
-<context>
-    <name>MEConfig</name>
-    <message>
-        <source>IP address</source>
-        <translation type="vanished">İP adresi</translation>
-    </message>
-    <message>
-        <source>Hardware detected</source>
-        <translation type="vanished">Donanım algılandı</translation>
-    </message>
-    <message>
-        <source>Unblock WiFi Devices</source>
-        <translation type="vanished">WiFi aygıtlarının engelini kaldırma</translation>
-    </message>
-    <message>
-        <source>Linux drivers</source>
-        <translation type="vanished">Linux sürücüleri</translation>
-    </message>
-    <message>
-        <source>Associated Linux drivers</source>
-        <translation type="vanished">Linux Sürücüleriyle İlişkili</translation>
-    </message>
-    <message>
-        <source>Load Driver</source>
-        <translation type="vanished">Sürücü Yükle</translation>
-    </message>
-    <message>
-        <source>Unload Driver</source>
-        <translation type="vanished">Sürücüyü Kaldır</translation>
-    </message>
-    <message>
-        <source>Blacklist Driver</source>
-        <translation type="vanished">Kara Listedeki Sürücüler</translation>
-    </message>
-    <message>
-        <source>Windows drivers</source>
-        <translation type="vanished">Windows sürücüleri</translation>
-    </message>
-    <message>
-        <source>Remove Driver</source>
-        <translation type="vanished">Sürücü Kaldır</translation>
-    </message>
-    <message>
-        <source>Add Driver</source>
-        <translation type="vanished">Sürücü Ekle</translation>
-    </message>
-    <message>
-        <source>About NDISwrapper</source>
-        <translation type="vanished">NDISwrapper Hakkında</translation>
-    </message>
-    <message>
-        <source>Install NDISwrapper</source>
-        <translation type="vanished">NDISwrapper Kur</translation>
-    </message>
-    <message>
-        <source>Uninstall NDISwrapper</source>
-        <translation type="vanished">NDISwrapper kurulumu kaldır</translation>
-    </message>
-    <message>
-        <source>Net diagnostics</source>
-        <translation type="vanished">Ağ tanılama</translation>
-    </message>
-    <message>
-        <source>Ping</source>
-        <translation type="vanished">Ping</translation>
-    </message>
-    <message>
-        <source>Target URL:</source>
-        <translation type="vanished">Hedef URL:</translation>
-    </message>
-    <message>
-        <source>Packets</source>
-        <translation type="vanished">Paketler</translation>
-    </message>
-    <message>
-        <source>Start</source>
-        <translation type="vanished">Başla</translation>
-    </message>
-    <message>
-        <source>Clear</source>
-        <translation type="vanished">Temizle</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">İptal</translation>
-    </message>
-    <message>
-        <source>Traceroute</source>
-        <translation type="vanished">İz yolu</translation>
-    </message>
-    <message>
-        <source>About...</source>
-        <translation type="vanished">Hakkında...</translation>
-    </message>
-    <message>
-        <source>Help</source>
-        <translation type="vanished">Yardım</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Kapat</translation>
-    </message>
-    <message>
-        <source>Alt+C</source>
-        <translation type="vanished">Alt+C</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -195,12 +17,12 @@
     <message>
         <location filename="../mainwindow.ui" line="76"/>
         <source>IP address</source>
-        <translation type="unfinished">İP adresi</translation>
+        <translation>İP adresi</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="112"/>
         <source>Hardware detected</source>
-        <translation type="unfinished">Donanım algılandı</translation>
+        <translation>Donanım algılandı</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="143"/>
@@ -227,37 +49,37 @@
     <message>
         <location filename="../mainwindow.ui" line="256"/>
         <source>Unblock WiFi Devices</source>
-        <translation type="unfinished">WiFi aygıtlarının engelini kaldırma</translation>
+        <translation>WiFi aygıtlarının engelini kaldırma</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="288"/>
         <source>Linux drivers</source>
-        <translation type="unfinished">Linux sürücüleri</translation>
+        <translation>Linux sürücüleri</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="300"/>
         <source>Associated Linux drivers</source>
-        <translation type="unfinished">Linux Sürücüleriyle İlişkili</translation>
+        <translation>Linux Sürücüleriyle İlişkili</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="309"/>
         <source>Load Driver</source>
-        <translation type="unfinished">Sürücü Yükle</translation>
+        <translation>Sürücü Yükle</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="372"/>
         <source>Unload Driver</source>
-        <translation type="unfinished">Sürücüyü Kaldır</translation>
+        <translation>Sürücüyü Kaldır</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="409"/>
         <source>Blacklist Driver</source>
-        <translation type="unfinished">Kara Listedeki Sürücüler</translation>
+        <translation>Kara Listedeki Sürücüler</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="428"/>
         <source>Windows drivers</source>
-        <translation type="unfinished">Windows sürücüleri</translation>
+        <translation>Windows sürücüleri</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="434"/>
@@ -267,22 +89,22 @@
     <message>
         <location filename="../mainwindow.ui" line="468"/>
         <source>Remove Driver</source>
-        <translation type="unfinished">Sürücü Kaldır</translation>
+        <translation>Sürücü Kaldır</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="479"/>
         <source>Add Driver</source>
-        <translation type="unfinished">Sürücü Ekle</translation>
+        <translation>Sürücü Ekle</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="520"/>
         <source>About NDISwrapper</source>
-        <translation type="unfinished">NDISwrapper Hakkında</translation>
+        <translation>NDISwrapper Hakkında</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="532"/>
         <source>Install NDISwrapper</source>
-        <translation type="unfinished">NDISwrapper Kur</translation>
+        <translation>NDISwrapper Kur</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="543"/>
@@ -292,131 +114,122 @@
     <message>
         <location filename="../mainwindow.ui" line="559"/>
         <source>Uninstall NDISwrapper</source>
-        <translation type="unfinished">NDISwrapper kurulumu kaldır</translation>
+        <translation>NDISwrapper kurulumu kaldır</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="591"/>
         <source>Net diagnostics</source>
-        <translation type="unfinished">Ağ tanılama</translation>
+        <translation>Ağ tanılama</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="603"/>
         <source>Ping</source>
-        <translation type="unfinished">Ping</translation>
+        <translation>Ping</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="609"/>
-        <location filename="../mainwindow.ui" line="719"/>
+        <location filename="../mainwindow.ui" line="726"/>
         <source>Target URL:</source>
-        <translation type="unfinished">Hedef URL:</translation>
+        <translation>Hedef URL:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="619"/>
         <source>Packets</source>
-        <translation type="unfinished">Paketler</translation>
+        <translation>Paketler</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="654"/>
-        <location filename="../mainwindow.ui" line="774"/>
+        <location filename="../mainwindow.ui" line="661"/>
+        <location filename="../mainwindow.ui" line="781"/>
         <source>Start</source>
-        <translation type="unfinished">Başla</translation>
+        <translation>Başla</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="671"/>
-        <location filename="../mainwindow.ui" line="791"/>
+        <location filename="../mainwindow.ui" line="678"/>
+        <location filename="../mainwindow.ui" line="798"/>
         <source>Clear</source>
-        <translation type="unfinished">Temizle</translation>
+        <translation>Temizle</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="685"/>
-        <location filename="../mainwindow.ui" line="805"/>
+        <location filename="../mainwindow.ui" line="692"/>
+        <location filename="../mainwindow.ui" line="812"/>
         <location filename="../mainwindow.cpp" line="1225"/>
         <source>Cancel</source>
-        <translation type="unfinished">İptal</translation>
+        <translation>İptal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="713"/>
+        <location filename="../mainwindow.ui" line="720"/>
         <source>Traceroute</source>
-        <translation type="unfinished">İz yolu</translation>
+        <translation>İz yolu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="729"/>
+        <location filename="../mainwindow.ui" line="736"/>
         <source>Hops</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="761"/>
-        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
-&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
-p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10.5pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="855"/>
+        <location filename="../mainwindow.ui" line="862"/>
         <source>About...</source>
-        <translation type="unfinished">Hakkında...</translation>
+        <translation>Hakkında...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="872"/>
+        <location filename="../mainwindow.ui" line="879"/>
         <source>Help</source>
-        <translation type="unfinished">Yardım</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="934"/>
-        <location filename="../mainwindow.cpp" line="1241"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Kapat</translation>
+        <translation>Yardım</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="941"/>
+        <location filename="../mainwindow.cpp" line="1241"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Kapat</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="948"/>
         <source>Alt+C</source>
-        <translation type="unfinished">Alt+C</translation>
+        <translation>Alt+C</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="157"/>
         <source>IP address from router:</source>
-        <translation type="unfinished">Yönlendiriciden İP adresi</translation>
+        <translation>Yönlendiriciden İP adresi</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="158"/>
         <source>External IP address:</source>
-        <translation type="unfinished">Harici İP adresi:</translation>
+        <translation>Harici İP adresi:</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="295"/>
         <location filename="../mainwindow.cpp" line="309"/>
         <location filename="../mainwindow.cpp" line="323"/>
         <source>&amp;Copy</source>
-        <translation type="unfinished">&amp;Kopyala</translation>
+        <translation>&amp;Kopyala</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="297"/>
         <location filename="../mainwindow.cpp" line="311"/>
         <location filename="../mainwindow.cpp" line="325"/>
         <source>Ctrl+C</source>
-        <translation type="unfinished">Ctrl+C</translation>
+        <translation>Ctrl+C</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="298"/>
         <location filename="../mainwindow.cpp" line="312"/>
         <location filename="../mainwindow.cpp" line="326"/>
         <source>Copy &amp;All</source>
-        <translation type="unfinished">&amp;Hepsini Kopyala</translation>
+        <translation>&amp;Hepsini Kopyala</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="300"/>
         <location filename="../mainwindow.cpp" line="314"/>
         <location filename="../mainwindow.cpp" line="328"/>
         <source>Ctrl+A</source>
-        <translation type="unfinished">Ctrl+A</translation>
+        <translation>Ctrl+A</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="365"/>
         <location filename="../mainwindow.cpp" line="387"/>
         <source>Traceroute not installed</source>
-        <translation type="unfinished">İz yolu kurulmadı</translation>
+        <translation>İz yolu kurulmadı</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="366"/>
@@ -442,7 +255,7 @@ p, li { white-space: pre-wrap; }
         <location filename="../mainwindow.cpp" line="395"/>
         <location filename="../mainwindow.cpp" line="447"/>
         <source>No destination host</source>
-        <translation type="unfinished">Hedef makine yok</translation>
+        <translation>Hedef makine yok</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="396"/>
@@ -498,7 +311,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../mainwindow.cpp" line="1141"/>
         <source>*.sys file not found</source>
-        <translation type="unfinished">*.sys dosyası bulunamadı</translation>
+        <translation>*.sys dosyası bulunamadı</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1141"/>
@@ -518,7 +331,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../mainwindow.cpp" line="1171"/>
         <source>Ndiswrapper driver removed.</source>
-        <translation type="unfinished">Ndiswrapper sürücüsü kaldırıldı.</translation>
+        <translation>Ndiswrapper sürücüsü kaldırıldı.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1218"/>
@@ -528,27 +341,27 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../mainwindow.cpp" line="1219"/>
         <source>Version: </source>
-        <translation type="unfinished">Sürüm</translation>
+        <translation>Sürüm</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1221"/>
         <source>Program for troubleshooting and configuring network for MX Linux</source>
-        <translation type="unfinished">MX Linux için ağ yapılandırma ve sorun giderme programı</translation>
+        <translation>MX Linux için ağ yapılandırma ve sorun giderme programı</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1222"/>
         <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation type="unfinished">Copyright (c) MEPIS LLC ve MX Linux</translation>
+        <translation>Copyright (c) MEPIS LLC ve MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1223"/>
         <source>License</source>
-        <translation type="unfinished">Ruhsat</translation>
+        <translation>Ruhsat</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1224"/>
         <source>Changelog</source>
-        <translation type="unfinished">Değişim günlüğü</translation>
+        <translation>Değişim günlüğü</translation>
     </message>
 </context>
 <context>
